@@ -2,7 +2,12 @@
 print.survivalmodel <- function(x, ...) {
   cat("\n", attr(x, "name"), "\n\n")
   cat("Call:\n ", deparse(x$call))
-  cat("\n\nResponse:\n  Surv(", paste0(colnames(x$y), collapse = ", "), ")\n", sep = "")
+  if (is.null(x[["y"]])) {
+    ynames <- x$ynames
+  } else {
+    ynames <- colnames(x$y)
+  }
+  cat("\n\nResponse:\n  Surv(", paste0(ynames, collapse = ", "), ")\n", sep = "")
   cat("Features:\n ", setcollapse(x$xnames), "\n")
 }
 
