@@ -3,18 +3,15 @@ setcollapse <- function(x) {
 }
 
 assert_surv_matrix <- function(x) {
-  if (!all(x <= 1 & x >= 0)) {
-    stop("Survival probabilities, x, must be 0 <= x <= 1")
-  }
+
   if (is.null(colnames(x)) ||
       !identical(order(as.numeric(colnames(x))), seq(ncol(x)))) {
     stop("Survival matrix column names must be increasing numeric")
   }
-  apply(1 - x, 1, function(.x) {
-    if (!identical(order(.x), seq(ncol(x)))) {
-      stop("Survival probabilities must be (non-strictly) decreasing")
-    }
-  })
+
+  if (!C_assert_increasing_surv(x)) {
+    stop("Survival probabilities must be (non-strictly) decreasing and between [0, 1]")
+  }
 
   invisible(NULL)
 }
@@ -29,4 +26,8 @@ fill_na <- function(x, along = 1) {
     }
     .x
   }))
-}
\ No newline at end of file
+}
+
+toproper <- function(str) {
+  paste0(toupper(substr(str, 1, 1)), substr(str, 2, 100))
+}
